/**
 * Sensor settings
 */

define('package/quiqqer/sensor/bin/SensorSettingWindow', [

    'qui/controls/windows/Confirm',
    'Ajax',

    'css!package/quiqqer/sensor/bin/SensorSettingWindow.css'

], function(QUIConfirm, Ajax)
{
    "use strict";

    return new Class({

        Extends : QUIConfirm,
        Type    : 'package/quiqqer/sensor/bin/SensorSettingWindow',


        options : {
            title     : 'Sensor hinzufügen',
            icon      : 'icon-plus',
            maxWidth  : 500,
            maxHeight : 300,

            sensorId : null // if you want to edit a sensor
        },

        initialize : function(options)
        {
            this.parent( options );

            this.$sensorType  = null;
            this.$sensorPin   = null;
            this.$sensorTitle = null;
        },

        /**
         * Open the Window
         *
         * @return {self}
         */
        open : function()
        {
            this.parent();
            this.Loader.show();

            var self    = this,
                Content = this.getContent(),
                id      = this.getId();

            Content.set(
                'html',

                '<div class="qui-package-sensor-add grid-100">' +
                    '<label for="sensor-type-'+ id +'" class="grid-30">Sensor-Type</label>' +
                    '<select name="sensor-type" id="sensor-type-'+ id +'" class="grid-50">' +
                        '<option value="GrovePi">GrovePi</option>' +
                    '</select>' +

                    '<div class="clear"></div>' +

                    '<label for="sensor-pin-'+ id +'" class="grid-30">Sensor-Pin</label>' +
                    '<input type="text" value="" name="sensor-pin" id="sensor-pin-'+ id +'" class="grid-50" />' +

                    '<div class="clear"></div>' +

                    '<label for="sensor-title-'+ id +'" class="grid-30">Title</label>' +
                    '<input type="text" value="" name="sensor-title" id="sensor-title-'+ id +'" class="grid-50" />' +
                '</div>'
            );

            this.$sensorType  = Content.getElement( '[name="sensor-type"]' );
            this.$sensorPin   = Content.getElement( '[name="sensor-pin"]' );
            this.$sensorTitle = Content.getElement( '[name="sensor-title"]' );

            if ( !this.getAttribute( 'sensorId' ) )
            {
                this.Loader.hide();
                return;
            }

            Ajax.get('package_quiqqer_sensor_ajax_get', function(result)
            {
                self.$sensorType.value  = result.sensorType;
                self.$sensorPin.value   = result.sensorPin;
                self.$sensorTitle.value = result.title;

                self.Loader.hide();
            }, {
                'package' : 'quiqqer/sensor',
                sensorId  : this.getAttribute( 'sensorId' )
            });
        },

        /**
         * Add the sensor to the list
         *
         * @return {self}
         */
        submit : function()
        {
            var self = this;

            if ( !this.getContent() ) {
                return this;
            }


            if ( this.getAttribute( 'sensorId' ) )
            {
                Ajax.post('package_quiqqer_sensor_ajax_edit', function(result)
                {
                    self.fireEvent( 'submit' );
                    self.close();
                }, {
                    'package'  : 'quiqqer/sensor',
                    sensorId   : this.getAttribute( 'sensorId' ),
                    sensorType : this.$sensorType.value,
                    sensorPin  : this.$sensorPin.value,
                    title      : this.$sensorTitle.value
                });

                return this;
            }

            Ajax.post('package_quiqqer_sensor_ajax_add', function(result)
            {
                self.fireEvent( 'submit' );
                self.close();
            }, {
                'package'  : 'quiqqer/sensor',
                sensorType : this.$sensorType.value,
                sensorPin  : this.$sensorPin.value,
                title      : this.$sensorTitle.value
            });

            return this;
        }
    });

});