<?php

/**
 * This File contains QUI\Sensor\Sensor
 */

namespace QUI\Sensor;

/**
 * Sensor parent class
 *
 * @author www.pcsg.de (Henning Leutz)
 */

class Sensor extends \QUI\QDOM
{
    /**
     * Id of the sensor
     * @var Integer
     */
    protected $_id;

    /**
     * Return the Sensor Pin (A0, A1 ...)
     * @var String
     */
    protected $_pin;

    /**
     * constructor
     *
     * @param Integer $id - id of the sensor
     */
    public function __construct($id)
    {
        $result = \QUI::getDataBase()->fetch(array(
            'from'  => \QUI::getDBTableName( 'sensors' ),
            'where' => array(
                'id' => $id
            ),
            'limit' => 1
        ));

        if ( !isset( $result[ 0 ] ) )
        {
            throw new \QUI\Exception(
                \QUI::getLocale()->get(
                    'package/sensor',
                    'exception.sensor.not.found'
                ),
                404
            );
        }

        $this->_id  = (int)$id;
        $this->_pin = $result[ 0 ][ 'sensorPin' ];

        unset( $result[ 0 ][ 'id' ] );

        $this->setAttributes( $result[ 0 ] );
    }

    /**
     * Return the sensor id
     *
     * @return Integer
     */
    public function getId()
    {
        return $this->_id;
    }

    /**
     * Return the pin
     *
     * @return Integer
     */
    public function getPin()
    {
        return $this->_pin;
    }

    /**
     * Return the history / stats data
     *
     * @return array
     */
    public function getData()
    {
        return \QUI::getDataBase()->fetch(array(
            'from' => \QUI::getDBTableName( 'sensordata' ),
            'where' => array(
                'id' => $this->getId()
            )
        ));
    }

    /**
     * Read the pin of the sensor
     * please overwrite in the sub classes
     *
     * @return String
     */
    public function readPin()
    {
        return '';
    }

    /**
     * read the pin and set the data to the database
     */
    public function setPinData()
    {
        $data = $this->readPin();

        \QUI::getDataBase()->insert(
            \QUI::getDBTableName( 'sensordata' ),
            array(
                'id'   => $this->getId(),
                'data' => $data,
                't'    => date('Y-m-d H:i:s')
            )
        );
    }

    /**
     * Return the sensor settings as an array
     *
     * @return array
     */
    public function toArray()
    {
        $attributes = $this->getAttributes();
        $attributes['id'] = $this->getId();

        return $attributes;
    }
}
